//////////////////////////////////////////////////////////////////////////////
// deKoratorconfig.cc
// -------------------
// DeKorator window decoration for KDE
// -------------------
// Autor: moty rahamim
// Email: moty.rahamim@gmail.com
// Based on Example-0.8 by David Johnson <david@usermode.org>
//////////////////////////////////////////////////////////////////////////////

#include <kconfig.h>
#include <klocale.h>
#include <kglobal.h>
#include <qbuttongroup.h>
#include <qgroupbox.h>
#include <qradiobutton.h>
#include <qwhatsthis.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qspinbox.h>
#include <qcheckbox.h>

#include "deKoratorconfig.h"
#include "configdialog.h"

#include <kurlrequester.h>

//////////////////////////////////////////////////////////////////////////////
// DeKoratorConfig()
// -------------
// Constructor

DeKoratorConfig::DeKoratorConfig( KConfig* config, QWidget* parent )
        : QObject( parent ), config_( 0 ), dialog_( 0 )
{
    // create the configuration object
    config_ = new KConfig( "kwindeKoratorrc" );
    KGlobal::locale() ->insertCatalogue( "kwin_deKorator_config" );

    // create and show the configuration dialog
    dialog_ = new ConfigDialog( parent );
    dialog_->show();

    // load the configuration
    load( config_ );

    // setup the connections
    connect( dialog_->titlealign, SIGNAL( clicked( int ) ),
             this, SLOT( selectionChanged( int ) ) );
    connect( dialog_->colorizeFramesChkBox, SIGNAL( clicked() ), SIGNAL( changed() ) );
    dialog_->framesPathKurl->setMode( 2 );
    connect( dialog_->colorizeButtonsChkBox, SIGNAL( clicked() ), SIGNAL( changed() ) );
    dialog_->buttonsPathKurl->setMode( 2 );
    connect( dialog_->framesPathKurl, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
    connect( dialog_->buttonsPathKurl, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
    connect( dialog_->hoverTypeCombo, SIGNAL( activated( const QString& ) ), SIGNAL( changed() ) );
    connect( dialog_->effectsAmount_SpinBox, SIGNAL( valueChanged( int ) ), SIGNAL( changed() ) );
    connect( dialog_->useMasks_Chkbox, SIGNAL( clicked() ), SIGNAL( changed() ) );
    connect( dialog_->masksPathKurl, SIGNAL( textChanged( const QString& ) ), SIGNAL( changed() ) );
    dialog_->masksPathKurl->setMode( 2 );

}

//////////////////////////////////////////////////////////////////////////////
// ~DeKoratorConfig()
// --------------
// Destructor

DeKoratorConfig::~DeKoratorConfig()
{
    if ( dialog_ ) delete dialog_;
    if ( config_ ) delete config_;
}

//////////////////////////////////////////////////////////////////////////////
// selectionChanged()
// ------------------
// Selection has changed

void DeKoratorConfig::selectionChanged( int )
{
    emit changed();
}

//////////////////////////////////////////////////////////////////////////////
// load()
// ------
// Load configuration data

void DeKoratorConfig::load( KConfig* )
{
    config_->setGroup( "General" );

    QString value = config_->readEntry( "TitleAlignment", "AlignHCenter" );
    QRadioButton *button = ( QRadioButton* ) dialog_->titlealign->child( value );
    if ( button ) button->setChecked( true );
    dialog_->colorizeFramesChkBox->setChecked( config_->readBoolEntry( "ColorizeFrames", false ) );
    dialog_->colorizeButtonsChkBox->setChecked( config_->readBoolEntry( "ColorizeButtons", false ) );
    dialog_->framesPathKurl->setURL( config_->readEntry( "FramesPath", "" ) );
    dialog_->buttonsPathKurl->setURL( config_->readEntry( "ButtonsPath", "" ) );
    dialog_->hoverTypeCombo->setCurrentText( config_->readEntry( "ButtonsHoverType", "To Gray" ) );
    int val = config_->readNumEntry("EffectAmount", 5);
    dialog_->effectsAmount_SpinBox->setValue(val);
    dialog_->useMasks_Chkbox->setChecked( config_->readBoolEntry( "UseMasks", false ) );
    dialog_->masksPathKurl->setURL( config_->readEntry( "MasksPath", "" ) );
}

//////////////////////////////////////////////////////////////////////////////
// save()
// ------
// Save configuration data

void DeKoratorConfig::save( KConfig* )
{
    config_->setGroup( "General" );

    QRadioButton *button = ( QRadioButton* ) dialog_->titlealign->selected();
    if ( button ) config_->writeEntry( "TitleAlignment", QString( button->name() ) );
    config_->writeEntry( "ColorizeFrames", dialog_->colorizeFramesChkBox->isChecked() );
    config_->writeEntry( "ColorizeButtons", dialog_->colorizeButtonsChkBox->isChecked() );
    config_->writeEntry( "FramesPath", dialog_->framesPathKurl->url() );
    config_->writeEntry( "ButtonsPath", dialog_->buttonsPathKurl->url() );
    config_->writeEntry( "ButtonsHoverType", dialog_->hoverTypeCombo->currentText() );
    config_->writeEntry( "EffectAmount", dialog_->effectsAmount_SpinBox->value() );
    config_->writeEntry( "UseMasks", dialog_->useMasks_Chkbox->isChecked() );
    config_->writeEntry( "MasksPath", dialog_->masksPathKurl->url() );
    config_->sync();
}

//////////////////////////////////////////////////////////////////////////////
// defaults()
// ----------
// Set configuration defaults

void DeKoratorConfig::defaults()
{
    QRadioButton * button =
        ( QRadioButton* ) dialog_->titlealign->child( "AlignHCenter" );
    if ( button ) button->setChecked( true );
    dialog_->colorizeFramesChkBox->setChecked( false );
    dialog_->colorizeButtonsChkBox->setChecked( false );
    dialog_->framesPathKurl->setURL( "" );
    dialog_->buttonsPathKurl->setURL( "" );
    dialog_->hoverTypeCombo->setCurrentText( "To Gray" );
    dialog_->effectsAmount_SpinBox->setValue( 5 );
    dialog_->useMasks_Chkbox->setChecked( config_->readBoolEntry( "UseMasks", false ) );
    dialog_->masksPathKurl->setURL( "" );
}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

extern "C"
{
    QObject* allocate_config( KConfig * config, QWidget * parent )
    {
        return ( new DeKoratorConfig( config, parent ) );
    }
}

#include "deKoratorconfig.moc"
